<?php
/**
 * Init in WplmsFlashcardsUnit
 *
 * @author 		VibeThemes
 * @category 	Admin
 * @package 	wplms_plugin
 * @version     1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Wplms_FlashcardsUnit_Init{

	public static $instance;
    
    public static function init(){

        if ( is_null( self::$instance ) )
            self::$instance = new Wplms_FlashcardsUnit_Init();
        return self::$instance;
    }

	private function __construct(){
		add_filter('wplms_course_creation_tabs',array($this,'flashcards_unit_unit'));
        add_action('wp_enqueue_scripts',array($this,'enqueue_script'));
        add_filter('bp_course_api_get_user_course_status_item_unit_meta',array($this,'bp_course_api_get_user_course_status_item_unit_meta'),10,3);  
    }


	function flashcards_unit_unit($tabs){
		$tabs['course_curriculum']['fields'][0]['curriculum_elements'][1]['types'][]= array(
			'id'=>'flashcards',
            'icon'=>'<svg class="flashcards_unit_icon" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path d="M16 16c0 1.104-.896 2-2 2h-12c-1.104 0-2-.896-2-2v-8c0-1.104.896-2 2-2h12c1.104 0 2 .896 2 2v8zm8-10l-6 4.223v3.554l6 4.223v-12z"/></svg>',
            'label'=>__('Flash Cards','wplms'),
            'fields'=>array(
                array(
                    'label'=> __('Unit title','wplms' ),
                    'type'=> 'title',
                    'id' => 'post_title',
                    'from'=>'post',
                    'value_type'=>'single',
                    'style'=>'full',
                    'default'=> __('Unit Name','wplms' ),
                    'desc'=> __('This is the title of the unit which is displayed on top of every unit','wplms' )
                    ),
                array(
                    'label'=> __('Unit Tag','wplms' ),
                    'type'=> 'taxonomy',
                    'taxonomy'=> 'module-tag',
                    'from'=>'taxonomy',
                    'value_type'=>'single',
                    'style'=>'assign_cat',
                    'id' => 'module-tag',
                    'default'=> __('Select a tag','wplms' ),
                ),
                array(
                    'label'=> __('What is the unit about','wplms' ),
                    'type'=> 'editor',
                    'style'=>'',
                    'value_type'=>'single',
                    'id' => 'post_content',
                    'from'=>'post',
                    'extras' => '',
                    'default'=> __('Enter description about the unit.','wplms' ),
                ),
                array(
                    'label'=> __('Unit duration','wplms' ),
                    'type'=> 'duration',
                    'style'=>'course_duration_stick_left',
                    'id' => 'wplms_duration',
                    'from'=> 'meta',
                    'default'=> array('value'=>9999,'parameter'=>86400),
                    'from'=>'meta',
                ),
                array( 
                    'label' => __('Free Unit','wplms'),
                    'desc'  => __('Set Free unit, viewable to all','wplms'), 
                    'id'    => 'wplms_free',
                    'type'  => 'switch',
                    'default'   => 'H',
                    'from'=>'meta',
                ),
                array(
                    'label' => __('Unit Forum','wplms'),
                    'desc'  => __('Connect Forum with Unit.','wplms'),
                    'id'    => 'wplms_forum',
                    'type'  => 'selectcpt',
                    'post_type' => 'forum',
                    'std'=>0,
                    'from'=>'meta',
                ),
                array(
                    'label' => __('Connect Assignments','wplms'),
                    'desc'  => __('Select an Assignment which you can connect with this Unit','wplms'),
                    'id'    => 'wplms_assignment',
                    'type'  => 'selectmulticpt', 
                    'post_type' => 'assignment',
                    'from'=>'meta',
                ),
                array(
                    'label' => __('Attachments','wplms'),
                    'desc'  => __('Display these attachments below units to be downloaded by students','wplms'),
                    'id'    => 'wplms_unit_attachments', 
                    'type'  => 'multiattachments', 
                    'from'=>'meta',
                ),
                array(
                    'label'=> __('Practice Questions','wplms' ),
                    'text'=> '',
                    'type'=> 'practice_questions',
                    'from'=>'meta',
                    'post_type'=>'question',
                    'id' => 'vibe_practice_questions',
                    'default'=> __('Select a type','wplms' ),
                    'buttons' => array(
                        'question_types'=>wplms_get_question_types(),
                    )
                ),
                array(
                    'label' => __('Add Flash Cards','wplms'),
                    'desc'  => __('Create Flash Cards for unit','wplms'),
                    'id'    => 'wplms_flashcards',
                    'type'  => 'wplms_flashcards', 
                    'from'=>'meta',
                    'default' =>'',
                )
            ),
		);
		return $tabs;
	}


	function enqueue_script(){
		$flashcards=apply_filters('wplms_flashcards_unit_script_args',array(
            'settings'=>array(),
            'translations'=>array(
                'flip'=>__('Flip', 'wplms'),
                'no_cards'=>__('No cards created!', 'wplms'),
            )
        ));
        if(function_exists('bp_is_user') && bp_is_user() || apply_filters('vibebp_enqueue_profile_script',false)){
            // wp_enqueue_script('wplms-flashcardsunit',plugins_url('../../../assets/js/unit-types/flash-cards.js',__FILE__),array('wp-element','wp-data'),WPLMS_PLUGIN_VERSION);
            // wp_localize_script('wplms-flashcardsunit','wplmsflashcardsunit',$flashcards);
            // wp_enqueue_style('wplms-flashcardsunit',plugins_url('../../../assets/css/unit-types/flash-cards.css',__FILE__),array(),WPLMS_PLUGIN_VERSION);
        }

	}

    function bp_course_api_get_user_course_status_item_unit_meta($meta,$course_id,$item_id){
        $type = get_post_meta($item_id,'vibe_type',true);
        if($type == 'flashcards' ){
            $meta['unit_type'] = 'wplms_flashcards';
            $meta['flashcards'] = get_post_meta($item_id,'wplms_flashcards',true);
        }
        return $meta;
    }

}

Wplms_FlashcardsUnit_Init::init();